# normalize_geometry

Normalize the orientation/order of a geometry using shapely.normalize.

**Arguments:**

- `geometry` (str): WKT string of the geometry.

**Returns:**

- Dictionary with status, message, and normalized geometry as WKT.
